# jpdeaths
jpdeaths visualizes the relationship between the number of Covid-19 deaths and age in Japan.<br>
Data was obtained from the following sites.<br>
https://covid19.mhlw.go.jp/public/opendata/deaths_cumulative_daily.csv<br>
It will be released as a PyPI tool in the near future.

# How to install jpdeaths
Recently published

# How to run jpdeaths
Recently published<br>
<img src="https://github.com/i-inose/jpdeaths/blob/main/result.png?raw=true">
